« get me outta code hell

hsmusic-wiki - HSMusic - static wiki software cataloguing collaborative creation
about summary refs log tree commit diff
path: root/src/data/composite
diff options
context:
space:
mode:
Diffstat (limited to 'src/data/composite')
-rw-r--r--src/data/composite/things/art-tag/index.js2
-rw-r--r--src/data/composite/things/art-tag/withAllDescendantArtTags.js (renamed from src/data/composite/things/art-tag/withAllDescendantTags.js)20
2 files changed, 11 insertions, 11 deletions
diff --git a/src/data/composite/things/art-tag/index.js b/src/data/composite/things/art-tag/index.js
index aedc3a0c..0c365ce2 100644
--- a/src/data/composite/things/art-tag/index.js
+++ b/src/data/composite/things/art-tag/index.js
@@ -1 +1 @@
-export {default as withAllDescendantTags} from './withAllDescendantTags.js';
+export {default as withAllDescendantArtTags} from './withAllDescendantArtTags.js';
diff --git a/src/data/composite/things/art-tag/withAllDescendantTags.js b/src/data/composite/things/art-tag/withAllDescendantArtTags.js
index 945e9f37..795f96cd 100644
--- a/src/data/composite/things/art-tag/withAllDescendantTags.js
+++ b/src/data/composite/things/art-tag/withAllDescendantArtTags.js
@@ -1,4 +1,4 @@
 // Gets all the tags which descend from this one - that means its own direct
 // descendants, but also all the direct and indirect desceands of each of those!
 // The results aren't specially sorted, but they won't contain any duplicates
 // (for example if two descendant tags both route deeper to end up including
@@ -12,31 +12,31 @@ import {withResolvedReferenceList} from '#composite/wiki-data';
 import {soupyFind} from '#composite/wiki-properties';
 
 export default templateCompositeFrom({
-  annotation: `withAllDescendantTags`,
+  annotation: `withAllDescendantArtTags`,
 
-  outputs: ['#allDescendantTags'],
+  outputs: ['#allDescendantArtTags'],
 
   steps: () => [
     raiseOutputWithoutDependency({
-      dependency: 'directDescendantTags',
+      dependency: 'directDescendantArtTags',
       mode: input.value('empty'),
-      output: input.value({'#allDescendantTags': []})
+      output: input.value({'#allDescendantArtTags': []})
     }),
 
     withResolvedReferenceList({
-      list: 'directDescendantTags',
+      list: 'directDescendantArtTags',
       find: soupyFind.input('artTag'),
     }),
 
     {
       dependencies: ['#resolvedReferenceList'],
       compute: (continuation, {
-        ['#resolvedReferenceList']: directDescendantTags,
+        ['#resolvedReferenceList']: directDescendantArtTags,
       }) => continuation({
-        ['#allDescendantTags']:
+        ['#allDescendantArtTags']:
           unique([
-            ...directDescendantTags,
-            ...directDescendantTags.flatMap(tag => tag.allDescendantTags),
+            ...directDescendantArtTags,
+            ...directDescendantArtTags.flatMap(artTag => artTag.allDescendantArtTags),
           ]),
       }),
     },
@@ -1,4 +1,4 @@
-// Gets all the tags which descend from this one - that means its own direct
+// Gets all the art tags which descend from this one - that means its own direct
 // descendants, but also all the direct and indirect desceands of each of those!
 // The results aren't specially sorted, but they won't contain any duplicates